##***************************************************
## R source code for auxiliary functions
## Created by Myriam Vimond
## Updated 12 Nov 2014
##***************************************************


## rescale()-------------------------------------
##    Rescales the image intensity from the interval [0,1] to the interval [a,1-a] for some data-dependent contraction factor 'a' such that the colour is left unchanged up yo one tone 
##    in particular, black is encoded by "a", white is encoded by "1-a"
## INPUT :
##    img = matrix
##     cData = number of graylevels, 
##           "bitmap" for two levels
##           "8bits" for 256 levels
##           "10bits" for 1024 levels
##           "12bits" for 4096 levels
## OUTPUT : 
##    matrix
rescale <- function(img,cData="8bits"){
  graylevels<- switch(cData,
                      "bitmap" = 1, 
                      "8bits" = 255,
                      "10bits" = 1023, 
                      "12bits" = 4095)
  a<-1/(2*graylevels)   
  a+img*(1-2*a)
}

## grille()-------------------------------------
##    coordinate grid for the pixels
## INPUT :
##     n1 = number of rows
##     n2 = number of columns
## OUTPUT : list
##     x1 = row coordinates for the pixel centers in any row of the observation domain (vector) 
##     x2 = column coordinates for the pixel centers in any row of the observation domain (vector)
##   dom1 = row coordinates for the pixel centers of the whole observation domain (matrix)
##   dom2 = column coordinates for the pixel centers of the whole observation domain (matrix) 
grille <- function(n1,n2){   
  x1 = (seq(from=1,to=n1,length.out=(n1)) - 1/2)/n1
  x2 = (seq(from=1,to=n2,length.out=(n2)) - 1/2)/n2    
  dom1 <- matrix(rep(x1,n2),nrow=n1,ncol=n2,byrow=FALSE)
  dom2 <- matrix(rep(x2,n1),nrow=n1,ncol=n2,byrow=TRUE)
  ## OUTPUT
  list(x2=x2,x1=x1,dom2=dom2,dom1=dom1)
}
