##***************************************************
## R source code for image functions
## Created by Myriam Vimond
## Updated 18 Nov 2014
##***************************************************

#' ---
#' title: "Illumination Estimation and Denoising Procedure"
#' author: "Segolen Geffray, Nicolas Klutchnikoff and Myriam Vimond"
#' date: "Nov 18th, 2014"
#' ---


## Set R working directory-----------------------------

## Specify the path to R working directory
workDir <- "/Users/geffray/GKV"
setwd(workDir)

## Load image-specific packages 
require(png)
require(rasterVis)

## Load user-defined functions
source('./lib/fnct01-grayImage.R')
source('./lib/fnct04-gkv-gray.R')

## Graphics parameters settings
old.par <- par(no.readonly = TRUE) # save default parameters
par(old.par)


## Load the data --------------------------------------

data <- read.grayImage('data/deep.png', nrow=422, ncol=NULL)  # read a subimage
write.grayImage(data,paste0('data/deep-orig.png'))  # save the subimage

n1 <- dim(data)[1] # number of rows
n2 <- dim(data)[2] # number of columns

## plot the histogram of pixel intensities
hist.grayImage(data)
## plot the loaded image
plot.grayImage(data)


## Run the GKV method-----------------------------------------------

out <- illumination(data, degree=c(5,6), method='gaussian')

## plot the denoised image
plot.grayImage(out$F)
## plot the estimated reflectance
plot.grayImage(out$R)
## display a contour plot of the estimated illumination
plot.grayIllumination(out$L)


## Run this to save the matrix out$R into a .png file which is located in the folder "figure"
write.grayImage(out$R,'./figure/deep-R.png')
## Run this to save the matrix out$Linto a .png file which is located in the folder "figure"
png(file="./figure/deep-L.png", width=ncol(out$L), height=(nrow(out$L)+50), res= 72)
plot.grayIllumination(out$L)
dev.off()


